summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDarren Salt <linux@youmustbejoking.demon.co.uk>2007-05-13 03:38:43 +0100
committerDarren Salt <linux@youmustbejoking.demon.co.uk>2007-05-13 03:38:43 +0100
commit0f6bdecec4561e7475c31ef8434785d9855001bc (patch)
treef46bca6ca8f0490ed597c8af0e3a3f08c602c11c
parentcbdad87eb7b57d4da0fd679f9b86c6f0aeacd5b3 (diff)
downloadxine-lib-0f6bdecec4561e7475c31ef8434785d9855001bc.tar.gz
xine-lib-0f6bdecec4561e7475c31ef8434785d9855001bc.tar.bz2
Correct the dvba:// MRL / tuner mismatch message.
-rw-r--r--src/input/input_dvb.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/input/input_dvb.c b/src/input/input_dvb.c
index ae7c0c21e..6536af8d8 100644
--- a/src/input/input_dvb.c
+++ b/src/input/input_dvb.c
@@ -2899,13 +2899,13 @@ static int dvb_plugin_open(input_plugin_t * this_gen)
{
fprintf(stderr,"input_dvb: 2a %x\n",tuner->feinfo.type);
/*
* This is dvbc://<channel name>:<qam tuning parameters>
*/
if (tuner->feinfo.type != FE_ATSC)
{
fprintf(stderr,"input_dvb: FAILED 1\n");
xprintf(this->class->xine, XINE_VERBOSITY_LOG,
- _("input_dvb: dvbc mrl specified but the tuner doesn't appear to be QAM (DVB-C)\n"));
+ _("input_dvb: dvba mrl specified but the tuner doesn't appear to be ATSC (DVB-A)\n"));
tuner_dispose(tuner);
return 0;
}
@@ -2899,13 +2899,13 @@ static int dvb_plugin_open(input_plugin_t * this_gen)
fprintf(stderr,"input_dvb: 2a %x\n",tuner->feinfo.type);
/*
- * This is dvbc://<channel name>:<qam tuning parameters>
+ * This is dvba://<channel name>:<atsc tuning parameters>
*/
if (tuner->feinfo.type != FE_ATSC)